% Devereux, Senay and Sutherland (2013) Figure 4

clear all

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

mfile='dss-matlab-model.txt';

[A1,A2,A3,A4,A5,NN,SIGMA,Z,nd,ns,nb,ne,nu,model] = modloadt(mfile);

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

nx=ne;
ns=nb;
nc=nu;

BB=zeros(nb+nu,1);

eval(model{1});
eval(model{2});

dr={'rb1','rb2'};

[dm,na]=size(dr);
for i=1:na
    ia(i)=inx(dr{i},Z)-ns-nx;
end

iW=inx('BX',Z);

icd=inx('cd',Z)-ns-nx;

BB(iW,1)=1;

iyx=inx('yx',Z)-ns-nx;

ire1=inx('re1',Z)-ns-nx;
ire2=inx('re2',Z)-ns-nx;
irb1=inx('rb1',Z)-ns-nx;
irb2=inx('rb2',Z)-ns-nx;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

val=0.00;

for ip=1:25;

RS(ip,1)=val+1.1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[A1,A2,A3,A4,A5,NN,SIGMA]=modeval(model,'DT',val,'HB',0.0,'ET',1.0,'SS',0,'SG',0,'SV',0,'SU',0,'SD',0,'CX3',1.0,'DX1',0,'DX2',0,'BM',10000,'DY',0.0);

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[F1, F2, F3, P1, P2, P3] = ls_solution(A1, A2, A3, BB, NN, nx, ns, nc);

[Q, M, nq] = ls2ds(F1, F2, P1, P2, P3, NN, 0);

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for i=1:na-1
    R1(i,:)=Q{ia(i),1}-Q{ia(na),1};
    R2(i,:)=Q{ia(i),2}-Q{ia(na),2};
end    

D1=Q{icd,1};
D2=Q{icd,2};

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

alpha1=inv(R2*SIGMA*D2'*R1'-R2*SIGMA*R2'*D1)*R2*SIGMA*D2';

af=[alpha1; -sum(alpha1)];

RS(ip,2:na+1)=af(:);

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

At1=A1;
At2=A2;
At3=A3;

for i=1:na-1
    At2(iW,ia(i)+ns)=alpha1(i);  
end
At2(iW,ia(na)+ns)=A2(iW,ia(na)+ns)-sum(alpha1);  

[Ft1, Ft2, Ft3, Pt1, Pt2, Pt3] = ls_solution(At1, At2, At3, BB, NN, nx, ns, nc);

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

YD=Pt1(iyx,:);

RX(1,:)=Pt1(irb1,:)-Pt1(irb2,:);

VRR=RX*SIGMA*RX';
VRY=RX*SIGMA*YD';

alpha2=-(1/2)*inv(VRR)*VRY;

XX=[RX; YD];
SS=XX*SIGMA*XX';

v1=SS(1,1);

vy1=SS(2,2);

s1=v1^(1/2);

sy1=vy1^(1/2);

cy1=SS(1,2);

cr1=cy1/(s1*sy1);

ae=-(1/2)*cr1*sy1/s1;

RS(ip,na+2)=-ae;

RS(ip,na+3)=cr1;

RS(ip,na+4)=s1;

RS(ip,na+5)=sy1;

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

GP=[NN zeros(nx,ns); Ft1 Ft2];
FP=[eye(nx,nx) zeros(nx,ns); zeros(ns,nx) eye(ns,ns); Pt1 Pt2];
LP=[eye(nx,nx); zeros(ns,nx)];
X=LP*SIGMA*LP';
V1=FP*X*FP';
ipi=inx('pi1',Z);
iy=inx('y1',Z);
iyd=inx('yd',Z);
iyxx=inx('yx',Z);
RS(ip,na+6)=100*V1(ipi,ipi)^0.5;
RS(ip,na+7)=100*V1(iy,iy)^0.5;
RS(ip,na+8)=V1(iyd,iyd)^0.5;
RS(ip,na+9)=V1(iyxx,iyxx)^0.5;
RS(ip,na+10)=RS(ip,na+9)/RS(ip,na+8);

val=val+2;

end

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure(1);

set(0,'DefaultAxesColorOrder',[0,0,0])
set(0,'DefaultAxesLineWidth',0.75)
set(0,'DefaultLineLineWidth',0.7)
set(0,'DefaultAxesLineStyle','-d')
set(0,'DefaultLineMarkerSize',1.5)
set(0,'DefaultLineMarkerFaceColor',[0,0,0])

set(gcf, 'PaperType', 'usletter');
set(gcf,'PaperPositionMode','manual');
set(gcf, 'PaperPosition', [1.5 0.5 18.57 25.92]);
set(gcf,'Position',[300,50,700,900]);
    
set(0,'DefaultAxesFontSize',7);

bs=0.18;
ht=0.13;
sp=0.06;
lhs=0.25;
rhs=0.535;

subplot(4,1,1); 
spp=get(gca,'Position');
spp(1)=lhs;
spp(2)=bs+3*(ht+sp);
spp(3)=rhs;
spp(4)=ht;
set(gca,'Position',spp);
plot(RS(:,1), RS(:,4));
title('(a) Bond holdings','FontSize',7,'Position',[25,5]);
xlabel('Inflation feedback coefficient: \chi','FontSize',7,'Position',[25,-28.8]);
ylim([-25,5]);
xlim([1,50]);

subplot(4,1,2);
spp=get(gca,'Position');
spp(1)=lhs;
spp(2)=bs+2*(ht+sp);
spp(3)=rhs;
spp(4)=ht;
set(gca,'Position',spp);
plot(RS(:,1), RS(:,5));
title('(b) Corr(r_B,\zeta_y)','FontSize',7,'Position',[25,1.1]);
xlabel('Inflation feedback coefficient: \chi','FontSize',7,'Position',[25,-1.38]);
ylim([-1.1,1.1]);
xlim([1,50]);

subplot(4,1,3); 
spp=get(gca,'Position');
spp(1)=lhs;
spp(2)=bs+1*(ht+sp);
spp(3)=rhs;
spp(4)=ht;
set(gca,'Position',spp);
plot(RS(:,1), RS(:,7));
title('(c) StDev(\zeta_y)','FontSize',7,'Position',[25,0.035]);
xlabel('Inflation feedback coefficient: \chi','FontSize',7,'Position',[25,0.0294]);
ylim([0.03,0.035]);
xlim([1,50]);

subplot(4,1,4); 
spp=get(gca,'Position');
spp(1)=lhs;
spp(2)=bs+0*(ht+sp);
spp(3)=rhs;
spp(4)=ht;
set(gca,'Position',spp);
plot(RS(:,1), RS(:,6));
title('(d) StDev(r_B)','FontSize',7,'Position',[25,0.01]);
xlabel('Inflation feedback coefficient: \chi','FontSize',7,'Position',[25,-0.0012]);
ylim([0.0,0.01]);
xlim([1,50]);

h = axes('Position',[0 0 1 1],'Visible','off');

clear ft;

ft1='Figure 4: Inflation stabilization and gross bond holdings:'; 
ft2='the correlation effect (cf. Devereux and Sutherland, 2008)';

text(0.28,0.96,ft1,'HorizontalAlignment','left');
text(0.27,0.942,ft2,'HorizontalAlignment','left');

