% Devereux, Senay and Sutherland (2013) Figure 5

clear all

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

mfile='dss-matlab-model.txt';

[A1,A2,A3,A4,A5,NN,SIGMA,Z,nd,ns,nb,ne,nu,model] = modloadt(mfile);

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

nx=ne;
ns=nb;
nc=nu;

BB=zeros(nb+nu,1);

eval(model{1});
eval(model{2});

dr={'re1','re2','rb1','rb2'};

[dm,na]=size(dr);
for i=1:na
    ia(i)=inx(dr{i},Z)-ns-nx;
end

iW=inx('BX',Z);

icd=inx('cd',Z)-ns-nx;

BB(iW,1)=1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

pvar{1}='TH';pval(1)=0.85;
pvar{2}='GM';pval(2)=0.90;
pvar{3}='DI';pval(3)=0.95;
pvar{4}='SM';pval(4)=0.0024;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for fn=1:4

    val=0.2;
    
    for ip=1:25;
        
        RST(ip,1)=val+1.1;
        
        [A1,A2,A3,A4,A5,NN,SIGMA]=modeval(model,'DT',val,pvar{fn},pval(fn));
        
        [F1, F2, F3, P1, P2, P3] = ls_solution(A1, A2, A3, BB, NN, nx, ns, nc);
        
        [Q, M, nq] = ls2ds(F1, F2, P1, P2, P3, NN, 0);
        
        for i=1:na-1
            R1(i,:)=Q{ia(i),1}-Q{ia(na),1};
            R2(i,:)=Q{ia(i),2}-Q{ia(na),2};
        end
        
        D1=Q{icd,1};
        D2=Q{icd,2};
        
        alpha1=inv(R2*SIGMA*D2'*R1'-R2*SIGMA*R2'*D1)*R2*SIGMA*D2';
        
        af=[alpha1; -sum(alpha1)];
        
        RST(ip,2)=af(2);
        RST(ip,3)=af(4);
        
        val=val+0.2;
        
    end
    
    RS(:,:,fn)=RST;

end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

pt{1}='(a) \theta=0.85, Equities';
pt{2}='(b) \theta=0.85, Bonds';
pt{3}='(c) \kappa=0.9, Equities';
pt{4}='(d) \kappa=0.9, Bonds';
pt{5}='(e) \vartheta=0.95, Equities';
pt{6}='(f) \vartheta=0.95, Bonds';
pt{7}='(g) \sigma_M=0.0024, Equities';
pt{8}='(h) \sigma_M=0.0024, Bonds';

set(0,'DefaultAxesFontSize',7);
set(0,'DefaultLineMarkerSize',3);

figure(1);

set(0,'DefaultAxesColorOrder',[0,0,0])
set(0,'DefaultAxesLineWidth',0.75)
set(0,'DefaultLineLineWidth',0.7)
set(0,'DefaultAxesLineStyle','-d')
set(0,'DefaultLineMarkerSize',1.5)
set(0,'DefaultLineMarkerFaceColor',[0,0,0])


set(gcf, 'PaperType', 'usletter');
set(gcf,'PaperPositionMode','manual');
set(gcf, 'PaperPosition', [1.5 0.5 18.57 25.92]);
set(gcf,'Position',[50,50,690,900]);


xtk=[1 2 3 4 5];
xlm=[1 5];

ylm{1}=[3 10];
ylm{2}=[-3 1];
ylm{3}=[3 10];
ylm{4}=[-3 1];
ylm{5}=[13 20];
ylm{6}=[-3 1];
ylm{7}=[6 13];
ylm{8}=[-3 1];

for i=1:8
    tmp=ylm{i};
    ps1(i)=tmp(1)-0.72;
    if ps1(i)<0
        ps1(i)=ps1(i)+0.3;
    end    
    ps2(i)=tmp(2);
end    

fnx=1;

for fn=1:4

    subplot(4,2,fnx);
    plot(RS(:,1,fn),RS(:,2,fn));
    xlim(xlm)
    ylim(ylm{fnx})
    set(gca,'XTick',xtk)
    title(pt{fnx},'FontSize',7,'Position',[3,ps2(fnx)]);
    xlabel('Inflation feedback coefficient: \chi','FontSize',7,'Position',[3,ps1(fnx)]);
    fnx=fnx+1;
    
    subplot(4,2,fnx);
    plot(RS(:,1,fn),RS(:,3,fn));
    xlim(xlm)
    ylim(ylm{fnx})
    set(gca,'XTick',xtk)
    title(pt{fnx},'FontSize',7,'Position',[3,ps2(fnx)]);
    xlabel('Inflation feedback coefficient: \chi','FontSize',7,'Position',[3,ps1(fnx)]);
    fnx=fnx+1;
    
end

h = axes('Position',[0 0 1 1],'Visible','off');

clear ft;
 
ft='Figure 5: Parameter variations.'; 

text(0.38,0.97,ft,'HorizontalAlignment','left');


